<?php

namespace App\Http\Controllers;

use App\Models\Letter;
use Illuminate\Http\Request;
use Illuminate\Support\Carbon;
use Barryvdh\DomPDF\Facade\Pdf;
use SimpleSoftwareIO\QrCode\Facades\QrCode;


class PDFController extends Controller
{
    public function generateQRCode($id)
    {
        // Construct the URL with the ID
        $urlWithId = "https://cabb.bangsamoro.gov.ph/cabb/{$id}";

        // Generate the QR code with the URL including the ID
        $qrCode = QrCode::size(50)->generate($urlWithId);

        // Save the QR code image to a temporary location
        $tempImagePath = public_path("imports/dist/img/qr_code}.png");
        file_put_contents($tempImagePath, $qrCode);

        return $tempImagePath;
    }

    public function generatePdf(Request $request)
    {


        $letter = Letter::find($request['id']);
        $letter_id = $letter->id;
        $issued_to = $letter->issued_to;
        $address = $letter->address;
        $nature_of_business = $letter->nature_of_business;
        $cabb_no = $letter->cabb_no;
        $or_no = $letter->or_no;
        $respone_no = $letter->respone_no;
        $series = $letter->series;
        $token = $letter->token;
       // dd($letter_id);

        // Generate the QR code and get its file path
        $tempImagePath = $this->generateQRCode($token);

      
        //DATE FORMAT CONVERTION
        $date_effect = Carbon::parse($letter->date_effective);
        $date_effective = $date_effect->format('F d, Y');
        $date_exp = Carbon::parse($letter->date_expired);
        $date_expired = $date_exp->format('F d, Y');


        $pdf = Pdf::loadView('pdf', [
            'issued_to' => $issued_to,
            'address' => $address,
            'nature_of_business' => $nature_of_business,
            'cabb_no' => $cabb_no,
            'or_no' => $or_no,
            'respone_no' => $respone_no,
            'series' => $series,
            'date_effective' => $date_effective,
            'date_expired' => $date_expired,
            'qrCodeImagePath' => $tempImagePath,
        ])->setPaper('a4', 'landscape');
        return $pdf->stream('pdf_with_qr_code.pdf');
    }
}
